@@ -214,7 +214,7 @@ void MapData::processElements()
         if (buildingLevels > 0) {
             const auto startLevel = e.tagValue(buildingMinLevelTag, levelTag, minLevelTag).toInt();
             qDebug() << startLevel << buildingLevels << e.url();
-            for (auto i = startLevel; i < buildingLevels; ++i) {
+            for (auto i = startLevel; i < startLevel + buildingLevels; ++i) {
                 addElement(i * 10, e, true);
             }
         }
